@@ -136,6 +136,9 @@ def run(args, environ):
                 do_action(
                     "clean", args, path, package, buildopts, install_prefix, environ
                 )
+        if args.builddir.is_dir():
+            log.info(f"Removing {args.builddir}")
+            shutil.rmtree(args.builddir, ignore_errors=True)
         return 0
 
     sys.stdout.write(
@@ -212,6 +215,9 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
     destdir = Path(
         get_build_var(package.name, "ROS_DESTDIR", args.destdir, env=environ)
     ).resolve()
+    homedir = Path(
+        get_build_var(package.name, "ROS_HOME", args.builddir / ".roshome", env=environ)
+    ).resolve()
     relative_install_prefix = install_prefix.relative_to("/")
     destdirs.add(destdir)
     package_suffix = re.sub(r"[^A-Za-z0-9]", "_", package.name)
@@ -221,6 +227,7 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
         "build_type": shlex.quote(build_type),
         "destdir": shlex.quote(str(destdir)),
         "dir": shlex.quote(str(path.resolve())),
+        "homedir": shlex.quote(str(homedir)),
         "package": shlex.quote(package.name),
         "package!id": package_suffix,
         "prefix": shlex.quote(str(install_prefix)),
@@ -235,6 +242,7 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
     for key in pybuild_per_package_keys:
         env[key[: -len(package_suffix) - 1]] = env[key]
         del env[key]
+    env["ROS_HOME"] = str(homedir)
     if install_prefix == Path("/usr") and "DEB_PYTHON_INSTALL_LAYOUT" not in env:
         env["DEB_PYTHON_INSTALL_LAYOUT"] = "deb"
     if install_prefix != Path("/usr"):
@@ -288,7 +296,8 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
         env["CPATH"] = ":".join(cpath)
 
     if action == "test":
-        env["ROS_IP"] = "127.0.0.1"
+        if "ROS_IP" not in env and "ROS_HOSTNAME" not in env:
+            env["ROS_IP"] = "127.0.0.1"
 
     if args.verbose:
         for key, value in env.items():
